# homeseer-python-client

A thin wrapper around the Homeseer HTTP JSON API

## Usage

```bash
pip install homeseer-client
```

```python
from homeseer_client import Homeseer

# Create a client instance
client = Homeseer(host="192.168.1.100", username="admin", password="password")

# Use the client to interact with your HomeSeer system
client.get_locations()

client.get_events()

client.get_control(ref=None)

client.get_status(
      ref=None,
      location1=None,
      location2=None,
      compress=False,
      everything=False
    )

client.control_device_by_value(ref, value)

client.control_device_by_label(ref, label)
```

## Development

```
 Choose a make command to run

  init      initialize a new python project
  install:  add a new package (make install <package>), or install all project dependencies from piplock.txt (make install)
  start     run local project
```

Generated by https://github.com/jritsema/cookiecutter-python
